@@ -549,8 +549,9 @@ gui_save_options <- function(general_opts,
       if (general_opts$download_server == "http" & http == "Not Available"
           & general_opts$sensor == "Aqua") { #nolint
         gWidgets::gmessage(
-          message = strwrap("The selected product/version is only available for the
-                        Terra sensor.\n\n Please switch sensor!", width = 300),
+          message = strwrap("The selected product/version is only available for
+                        the Terra sensor.\n\n Please switch sensor!",
+                            width = 300),
           title   = "Warning")
         gui_env$check_save_opts <- FALSE
       }
